summaryrefslogtreecommitdiffstats
path: root/chrome/views/custom_frame_window.cc
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
commit4d0bd1045bc0df8daea2a5626e73906cb074631b (patch)
tree6794b895e236b68c2f7de1163dfb1c554646364c /chrome/views/custom_frame_window.cc
parent7609533b68dcbeaa80bf712dd84726d1da8d3f8a (diff)
downloadchromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.zip
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.gz
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.bz2
Rename ViewContainer to Container and HWNDViewContainer to ContainerWin.
http://crbug.com/3430 Review URL: http://codereview.chromium.org/7376 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@3441 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/views/custom_frame_window.cc')
-rw-r--r--chrome/views/custom_frame_window.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/views/custom_frame_window.cc b/chrome/views/custom_frame_window.cc
index 046210a..9bd9758 100644
--- a/chrome/views/custom_frame_window.cc
+++ b/chrome/views/custom_frame_window.cc
@@ -525,9 +525,9 @@ gfx::Size DefaultNonClientView::GetPreferredSize() {
void DefaultNonClientView::ViewHierarchyChanged(bool is_add,
View* parent,
View* child) {
- // Add our Client View as we are added to the ViewContainer so that if we are
+ // Add our Client View as we are added to the Container so that if we are
// subsequently resized all the parent-child relationships are established.
- if (is_add && GetViewContainer() && child == this)
+ if (is_add && GetContainer() && child == this)
AddChildView(container_->client_view());
}
@@ -920,7 +920,7 @@ void CustomFrameWindow::SetClientView(ClientView* cv) {
DCHECK(cv && !client_view() && GetHWND());
set_client_view(cv);
// For a CustomFrameWindow, the non-client view is the root.
- HWNDViewContainer::SetContentsView(non_client_view_);
+ ContainerWin::SetContentsView(non_client_view_);
// When the non client view is added to the view hierarchy, it will cause the
// client view to be added as well.
}
@@ -970,7 +970,7 @@ void CustomFrameWindow::SizeWindowToDefault() {
}
///////////////////////////////////////////////////////////////////////////////
// CustomFrameWindow, HWNDViewContainer overrides:
void CustomFrameWindow::OnGetMinMaxInfo(MINMAXINFO* minmax_info) {
// We handle this message so that we can make sure we interact nicely with
@@ -970,7 +970,7 @@ void CustomFrameWindow::SizeWindowToDefault() {
}
///////////////////////////////////////////////////////////////////////////////
-// CustomFrameWindow, HWNDViewContainer overrides:
+// CustomFrameWindow, ContainerWin overrides:
void CustomFrameWindow::OnGetMinMaxInfo(MINMAXINFO* minmax_info) {
// We handle this message so that we can make sure we interact nicely with